@@ -67,9 +67,12 @@ namespace CONFIG
     // JD ホームページのアドレス
     const std::string& get_url_jdhp();
 
-    // 2chの認証サーバ
+    // 2chの認証サーバのアドレス
     const std::string& get_url_login2ch();
 
+    // p2の認証サーバのアドレス
+    const std::string& get_url_loginp2();
+
     // bbsmenu.htmlのURL
     const std::string& get_url_bbsmenu();    
 
@@ -140,7 +143,7 @@ namespace CONFIG
     // ローダのタイムアウト値
     const int get_loader_timeout();
     const int get_loader_timeout_post();
-    const int get_loader_timeout_img();
+    const int get_loader_timeout_data();
     const int get_loader_timeout_checkupdate();
 
     // ipv6使用
@@ -164,6 +167,11 @@ namespace CONFIG
     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
     const bool get_idpopup_by_mo();
 
+    // 画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+    const int get_imgemb_interp();
+    const int get_imgmain_interp();
+    const int get_imgpopup_interp();
+
     // 画像ポップアップサイズ
     const int get_imgpopup_width();
     const int get_imgpopup_height();
@@ -374,20 +382,20 @@ namespace CONFIG
     void set_abone_hour_thread( const int hour );
 
     // articleviewでのレスの全体あぼーん
-    std::list< std::string >& get_list_abone_name(); // 名前
-    std::list< std::string >& get_list_abone_word(); // ワード
-    std::list< std::string >& get_list_abone_regex(); // 正規表現
+    const std::list< std::string >& get_list_abone_name(); // 名前
+    const std::list< std::string >& get_list_abone_word(); // ワード
+    const std::list< std::string >& get_list_abone_regex(); // 正規表現
 
-    void set_list_abone_name( std::list< std::string >& name );
-    void set_list_abone_word( std::list< std::string >& word );
-    void set_list_abone_regex( std::list< std::string >& regex );
+    void set_list_abone_name( const std::list< std::string >& name );
+    void set_list_abone_word( const std::list< std::string >& word );
+    void set_list_abone_regex( const std::list< std::string >& regex );
 
     // デフォルトで透明、連鎖あぼーんをするか
     const bool get_abone_transparent();
-    void set_abone_transparent( bool set );
+    void set_abone_transparent( const bool set );
 
     const bool get_abone_chain();
-    void set_abone_chain( bool set );
+    void set_abone_chain( const bool set );
 
     // 右ペーンが空の時にサイドバーを閉じるか
     const bool get_expand_sidebar();
@@ -404,6 +412,16 @@ namespace CONFIG
     // スレをお気に入りに追加したときにしおりをセットする
     const bool get_bookmark_drop();
 
+    // お気に入りの更新チェック時に板の更新もチェックする
+    const bool get_check_update_board();
+
+    // Ctrl+qでウィンドウを閉じない
+    const bool get_disable_close();
+
+    // まちBBSの取得に offlaw.cgi を使用する
+    const bool get_use_machi_offlaw();
+    void set_use_machi_offlaw( const bool set );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
