@@ -5,6 +5,7 @@
 
 #include "boardjbbs.h"
 #include "articlejbbs.h"
+#include "articlehash.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
@@ -13,6 +14,7 @@
 #include "global.h"
 
 #include <sstream>
+#include <cstring>
 
 using namespace DBTREE;
 
@@ -20,7 +22,7 @@ using namespace DBTREE;
 BoardJBBS::BoardJBBS( const std::string& root, const std::string& path_board, const std::string& name )
     : BoardBase( root, path_board, name )
 {
-    // dat のURLは特殊なので url_datpath()をオーバロードする
+    // dat のURLは特殊なので url_datpath()をオーバライドする
     set_path_dat( "" );
 
     set_path_readcgi( "/bbs/read.cgi" );
@@ -29,7 +31,7 @@ BoardJBBS::BoardJBBS( const std::string& root, const std::string& path_board, co
     set_subjecttxt( "subject.txt" );
     set_ext( "" );
     set_id( path_board.substr( 1 ) ); // 先頭の '/' を除く  
-    set_charset( "EUC-JP" );
+    set_charset( "EUCJP-WIN" );
 }
 
 
@@ -56,12 +58,17 @@ bool BoardJBBS::is_valid( const std::string& filename )
 //
 // cached : HDD にキャッシュがあるならtrue
 //
-ArticleBase* BoardJBBS::append_article( const std::string& id, bool cached )
+ArticleBase* BoardJBBS::append_article( const std::string& datbase, const std::string& id, const bool cached )
 {
     if( empty() ) return get_article_null();
 
-    ArticleBase* article = new DBTREE::ArticleJBBS( url_datbase(), id, cached );
-    if( article ) get_list_article().push_back( article );
+    ArticleBase* article = new DBTREE::ArticleJBBS( datbase, id, cached );
+    if( article ){
+        get_hash_article()->push( article );
+
+        // 最大レス数セット
+        article->set_number_max( get_number_max_res() );
+    }
     else return get_article_null();
 
     return article;
@@ -104,7 +111,7 @@ const std::string BoardJBBS::create_newarticle_message( const std::string& subje
             << "&MESSAGE=" << MISC::charset_url_encode( msg, get_charset() )
             << "&DIR="     << dir
             << "&BBS="     << bbs
-            << "&TIME="    << time_modified();
+            << "&TIME="    << get_time_modified();
 
 #ifdef _DEBUG
     std::cout << "BoardJBBS::create_newarticle_message " << ss_post.str() << std::endl;
@@ -149,6 +156,7 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
    
     const char* pos = str_subject_txt;
     char str_tmp[ 1024 ];
+    const std::string datbase = url_datbase();
 
     ArticleBase* article_first = NULL;
 
@@ -213,14 +221,14 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
 #endif
 
         // DBに登録されてるならarticle クラスの情報更新
-        ArticleBase* article = get_article( id );
+        ArticleBase* article = get_article( datbase, id );
 
         // DBにないなら新規に article クラスを追加
         //
         // なお BoardBase::receive_finish() のなかで append_all_article_in_cache() が既に呼び出されているため
         // DBに無いということはキャッシュにも無いということ。よって append_article()で  cached = false
 
-        if( article->empty() ) article = append_article( id, false );
+        if( article->empty() ) article = append_article( datbase, id, false );
 
         // スレ情報更新
         if( article ){
