@@ -41,7 +41,7 @@ namespace DBTREE
     const std::string url_datbase( const std::string& url );
 
     // dat型のurlに変換
-    const std::string url_dat( const std::string& url, int& num_from, int& num_to ); 
+    const std::string url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str ); 
 
     // dat型のurlに変換(簡易版)
     const std::string url_dat( const std::string& url ); 
@@ -68,7 +68,7 @@ namespace DBTREE
         );
 
     // 板移転
-    void move_board( const std::string& url_old, const std::string& url_new );
+    const bool move_board( const std::string& url_old, const std::string& url_new );
 
     // bbslist系
     const XML::Document& get_xml_document();
@@ -97,14 +97,17 @@ namespace DBTREE
     const std::string board_cookie_for_write( const std::string& url );
     const std::list< std::string >& board_list_cookies_for_write( const std::string& url );
     void board_set_list_cookies_for_write( const std::string& url, const std::list< std::string>& list_cookies );        
-    const std::string board_hana_for_write( const std::string& url );
-    void board_set_hana_for_write( const std::string& url, const std::string& hana );
+    const std::string board_keyword_for_write( const std::string& url );
+    void board_set_keyword_for_write( const std::string& url, const std::string& keyword );
+    void board_analyze_keyword_for_write( const std::string& url, const std::string& html );
     const std::string board_basicauth( const std::string& url );
     const std::string board_ext( const std::string& url );
+    const int board_status( const std::string& url );
     const int board_code( const std::string& url );
     const std::string board_str_code( const std::string& url );
     void board_save_info( const std::string& url );
-    void board_download_subject( const std::string& url );
+    void board_download_subject( const std::string& url, const std::string& url_update_view );
+    const bool board_is_loading( const std::string& url );
     void board_stop_load( const std::string& url );
     std::list< DBTREE::ArticleBase* >& board_list_subject( const std::string& url );
     const int board_view_sort_column( const std::string& url );
@@ -120,12 +123,14 @@ namespace DBTREE
     const int board_get_mode_local_proxy( const std::string& url );
     const std::string& board_get_local_proxy( const std::string& url );
     const int board_get_local_proxy_port( const std::string& url );
+    const std::string& board_get_local_proxy_basicauth( const std::string& url );
     void board_set_mode_local_proxy( const std::string& url, int mode );
     void board_set_local_proxy( const std::string& url, const std::string& proxy );
     void board_set_local_proxy_port( const std::string& url, int port );
     const int board_get_mode_local_proxy_w( const std::string& url );
     const std::string& board_get_local_proxy_w( const std::string& url );
     const int board_get_local_proxy_port_w( const std::string& url );
+    const std::string& board_get_local_proxy_basicauth_w( const std::string& url );
     void board_set_mode_local_proxy_w( const std::string& url, int mode );
     void board_set_local_proxy_w( const std::string& url, const std::string& proxy );
     void board_set_local_proxy_port_w( const std::string& url, int port );
@@ -139,10 +144,30 @@ namespace DBTREE
     const time_t board_samba_sec( const std::string& url );
     void board_set_samba_sec( const std::string& url, time_t sec );
     time_t board_write_leftsec( const std::string& url );
+
+    // 更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
+    // update == true の時に表示。falseなら戻す
+    void board_show_updateicon( const std::string& url, const bool update );
+
+    // 板の更新チェック時に、更新チェックを行うスレのアドレスのリスト
+    // キャッシュが存在し、かつdat落ちしていないで新着数が0のスレを速度の順でソートして返す
+    const std::list< std::string > board_get_check_update_articles( const std::string& url );
+
+    // datファイルのインポート
+    // 成功したらdat型のurlを返す
+    const std::string board_import_dat( const std::string& url, const std::string& filename );
+
+    // 各板に属する全スレの書き込み履歴のリセット
+    void board_clear_all_post_history( const std::string& url );
+
     const int board_get_number_max_res( const std::string& url );
     void board_set_number_max_res( const std::string& url, const int number );
     const time_t board_get_live_sec( const std::string& url );
     void board_set_live_sec( const std::string& url, time_t sec );
+    const time_t board_last_access_time( const std::string& url );
+
+    // 全スレの書き込み履歴のリセット
+    void clear_all_post_history();
 
     // 全板の情報ファイル読み込み
     void read_boardinfo_all();
@@ -160,12 +185,11 @@ namespace DBTREE
     const std::string article_since_date( const std::string& url );
     const time_t article_time_modified( const std::string& url ); // スレの更新時間( time_t )
     const std::string article_date_modified( const std::string& url ); // スレの更新時間( 文字列 )
+    void article_set_date_modified( const std::string& url, const std::string& date ); // スレの更新時間( 文字列 )をセット
     const int article_hour( const std::string& url );
     const time_t article_write_time( const std::string& url );
     const std::string article_write_date( const std::string& url );
-    const time_t article_write_pass( const std::string& url );
     const int article_status( const std::string& url );
-    void article_reset_status( const std::string& url );
     const int article_code( const std::string& url );
     const std::string article_str_code( const std::string& url );
     const std::string article_ext_err( const std::string& url );
@@ -177,9 +201,14 @@ namespace DBTREE
     const int article_number_new( const std::string& url );    
     const bool article_is_loading( const std::string& url );
     void article_download_dat( const std::string& url, const bool check_update );
+    void article_set_url_pre_article( const std::string& url, const std::string& url_pre_article );
+    void article_copy_article_info( const std::string& url, const std::string& url_src );
     void article_stop_load( const std::string& url );
     const int article_get_speed( const std::string& url );
 
+    // 書き込み履歴のリセット
+    void article_clear_post_history( const std::string& url );
+
     // キャッシュ削除
     // cache_only == true の時はキャッシュだけ削除してスレ情報は消さない
     void delete_article( const std::string& url, const bool cache_only );  
@@ -190,13 +219,18 @@ namespace DBTREE
     void article_update_writetime( const std::string& url );
     size_t article_lng_dat( const std::string& url );
 
-    // agent, プロキシ
-
+    // ユーザーエージェント
     const std::string& get_agent( const std::string& url );
-    const std::string get_proxy_host( const std::string& url ); // 読み込み用
+
+    // 読み込み用プロキシ
+    const std::string get_proxy_host( const std::string& url );
     const int get_proxy_port( const std::string& url );
-    const std::string get_proxy_host_w( const std::string& url ); // 書き込み用
+    const std::string get_proxy_basicauth( const std::string& url );
+
+    // 書き込み用プロキシ
+    const std::string get_proxy_host_w( const std::string& url ); 
     const int get_proxy_port_w( const std::string& url );
+    const std::string get_proxy_basicauth_w( const std::string& url );
 
     // ローカルルール
     const std::string localrule( const std::string& url );
@@ -233,45 +267,51 @@ namespace DBTREE
     const std::string create_newarticle_message( const std::string& url, const std::string& subject,
                                                  const std::string& name, const std::string& mail, const std::string& msg );
 
+    // 書き込み時のリファラ
+    const std::string get_write_referer( const std::string& url );
+
     // あぼーん関係
 
-    // 板レベルのあぼーん
+    // 板レベルでのあぼーん情報
     // グローバルなあぼーん情報は globalconf が管理
-    std::list< std::string > get_abone_list_id_board( const std::string& url );
-    std::list< std::string > get_abone_list_name_board( const std::string& url );
-    std::list< std::string > get_abone_list_word_board( const std::string& url );
-    std::list< std::string > get_abone_list_regex_board( const std::string& url );
+    const std::list< std::string >& get_abone_list_id_board( const std::string& url );
+    const std::list< std::string >& get_abone_list_name_board( const std::string& url );
+    const std::list< std::string >& get_abone_list_word_board( const std::string& url );
+    const std::list< std::string >& get_abone_list_regex_board( const std::string& url );
 
-    // 板レベルのあぼーん情報の同時セットと更新
+    // 板レベルでのあぼーん状態のリセット(情報セットとスレビューの表示更新を同時におこなう)
     void reset_abone_board( const std::string& url,
-                            std::list< std::string >& ids, std::list< std::string >& names,
-                            std::list< std::string >& words, std::list< std::string >& regexs );
+                            const std::list< std::string >& ids,
+                            const std::list< std::string >& names,
+                            const std::list< std::string >& words,
+                            const std::list< std::string >& regexs );
 
-    // 個別のあぼーん情報のセットと更新
+    // 板レベルでのあぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう。スレビューの表示更新も同時におこなう)
     void add_abone_id_board( const std::string& url, const std::string& id );
     void add_abone_name_board( const std::string& url, const std::string& name );
     void add_abone_word_board( const std::string& url, const std::string& word );
 
-    // 全boardbaseクラスのあぼーん状態の更新
-    // ビューの再描画も同時に行われる
-    void update_abone_all_board();
-
-    // 指定したboardbaseクラスのあぼーん状態の更新
-    // ビューの再描画も同時に行われる
-    void update_abone_board( const std::string& url );
-
-    // スレあぼーん
+    // スレあぼーん情報
     // グローバルなあぼーん情報は globalconf が管理
-    std::list< std::string > get_abone_list_thread( const std::string& url );
-    std::list< std::string > get_abone_list_word_thread( const std::string& url );
-    std::list< std::string > get_abone_list_regex_thread( const std::string& url );
-    std::vector< char > get_abone_vec_res( const std::string& url );
+    const std::list< std::string >& get_abone_list_thread( const std::string& url );
+    const std::list< std::string >& get_abone_list_word_thread( const std::string& url );
+    const std::list< std::string >& get_abone_list_regex_thread( const std::string& url );
+    const std::vector< char >& get_abone_vec_res( const std::string& url );
     const int get_abone_number_thread( const std::string& url );
     const int get_abone_hour_thread( const std::string& url );
 
-    // スレあぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+    // subject.txtのロード後にdat落ちしたスレッドをスレあぼーんのリストから取り除く
+    void remove_old_abone_thread( const std::string& url );
+
+    // スレあぼーん情報を更新した時、全boardbaseクラスに対応するスレ一覧の表示を更新させる
+    // CONFIG::set_abone_number_thread() などでグローバル設定をした後などに呼び出す
+    void update_abone_thread();
+
+    // スレあぼーん状態のリセット(情報セットとスレ一覧の表示更新を同時におこなう)
     void reset_abone_thread( const std::string& url,
-                             std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
+                             const std::list< std::string >& threads,
+                             const std::list< std::string >& words,
+                             const std::list< std::string >& regexs,
                              const int number, const int hour );
 
     //
@@ -283,16 +323,19 @@ namespace DBTREE
 
     // レスあぼーん
     // グローバルなあぼーん情報は globalconf が管理
-    std::list< std::string > get_abone_list_id( const std::string& url );
-    std::list< std::string > get_abone_list_name( const std::string& url );
-    std::list< std::string > get_abone_list_word( const std::string& url );
-    std::list< std::string > get_abone_list_regex( const std::string& url );
+    const std::list< std::string >& get_abone_list_id( const std::string& url );
+    const std::list< std::string >& get_abone_list_name( const std::string& url );
+    const std::list< std::string >& get_abone_list_word( const std::string& url );
+    const std::list< std::string >& get_abone_list_regex( const std::string& url );
 
     // 全あぼーん情報の同時セットと更新
-    void reset_abone( const std::string& url, std::list< std::string >& ids, std::list< std::string >& names,
-                      std::list< std::string >& words, std::list< std::string >& regexs,
-                      std::vector< char >& vec_abone_res,
-                      bool transparent, bool chain);
+    void reset_abone( const std::string& url,
+                      const std::list< std::string >& ids,
+                      const std::list< std::string >& names,
+                      const std::list< std::string >& words,
+                      const std::list< std::string >& regexs,
+                      const std::vector< char >& vec_abone_res,
+                      const bool transparent, const bool chain, const bool age );
 
     // 個別のあぼーん情報のセットと更新
     void set_abone_res( const std::string& url, const int number, const bool set );
@@ -302,23 +345,26 @@ namespace DBTREE
 
     // 透明あぼーん
     const bool get_abone_transparent( const std::string& url );
-    void set_abone_transparent( const std::string& url, bool set );
+    void set_abone_transparent( const std::string& url, const bool set );
 
     // 連鎖あぼーん
     const bool get_abone_chain( const std::string& url );
-    void set_abone_chain( const std::string& url, bool set );
+    void set_abone_chain( const std::string& url, const bool set );
 
+    // ageあぼーん
+    const bool get_abone_age( const std::string& url );
+    void set_abone_age( const std::string& url, const bool set );
 
     //　ブックマーク関係
 
     // スレのブックマーク
     const bool is_bookmarked_thread( const std::string& url );
-    void set_bookmarked_thread( const std::string& url, bool bookmarked );
+    void set_bookmarked_thread( const std::string& url, const bool bookmarked );
 
     // レスのブックマーク
     const int get_num_bookmark( const std::string& url );
-    const bool is_bookmarked( const std::string& url, int number );
-    void set_bookmark( const std::string& url, int number, bool set );
+    const bool is_bookmarked( const std::string& url, const int number );
+    void set_bookmark( const std::string& url, const int number, const bool set );
 }
 
 #endif
