@@ -5,6 +5,7 @@
 
 #include "messageadmin.h"
 #include "messagewin.h"
+#include "toolbar.h"
 
 #include "skeleton/view.h"
 #include "skeleton/msgdiag.h"
@@ -36,7 +37,7 @@ using namespace MESSAGE;
 
 
 MessageAdmin::MessageAdmin( const std::string& url )
-    : SKELETON::Admin( url )
+    : SKELETON::Admin( url ), m_toolbar( NULL ), m_toolbar_preview( NULL )
 {
     get_notebook()->set_show_tabs( false );
 }
@@ -47,12 +48,31 @@ MessageAdmin::~MessageAdmin()
 #ifdef _DEBUG
     std::cout << "MessageAdmin::~MessageAdmin\n";
 #endif 
+
+    if( m_toolbar ) delete m_toolbar;
+    if( m_toolbar_preview ) delete m_toolbar_preview;
+}
+
+
+
+void MessageAdmin::show_entry_new_subject( bool show )
+{
+    if( m_toolbar ) m_toolbar->show_entry_new_subject( show );
+}
+
+
+std::string MessageAdmin::get_new_subject()
+{
+    if( m_toolbar ) return m_toolbar->get_new_subject();
+
+    return std::string();
 }
 
 
 //
 // ローカルコマンド実行
 //
+// virtual
 void MessageAdmin::command_local( const COMMAND_ARGS& command )
 {
 #ifdef _DEBUG
@@ -61,20 +81,44 @@ void MessageAdmin::command_local( const COMMAND_ARGS& command )
 
     SKELETON::View *view = get_current_view();
 
-    // 書き込み実行
-    if( command.command == "exec_Write" ){
+    // 書き込みボタンにフォーカスを移す
+    if( command.command == "focus_button_write" ){
+        if( get_notebook()->get_current_toolbar() == TOOLBAR_MESSAGE ) m_toolbar->focus_button_write();
+        else m_toolbar_preview->focus_button_write();
+    }
+    // プレビュー切り替え
+    else if( command.command == "toggle_preview" ){
         if( view ) view->set_command( command.command );
     }
-    // 書き込みボタンにフォーカスを移す
-    else if( command.command == "focus_write" ){
+    // undo
+    else if( command.command == "undo_text" ){
         if( view ) view->set_command( command.command );
     }
+    // 下書き挿入
+    else if( command.command == "insert_draft" ){
+        if( view ) view->set_command( command.command );
+    }
+    // 通常のツールバーに表示切り替え
+    else if( command.command == "switch_toolbar_message" ){
+        if( view ){
+            get_notebook()->set_current_toolbar( TOOLBAR_MESSAGE, view );
+            m_toolbar->set_active_previewbutton( false );
+        }
+    }
+    // プレビューツールバーに表示切り替え
+    else if( command.command == "switch_toolbar_preview" ){
+        if( view ){
+            get_notebook()->set_current_toolbar( TOOLBAR_PREVIEW, view );
+            m_toolbar_preview->set_active_previewbutton( true );
+        }
+    }
 }
 
 
 //
 // 閉じる
 //
+// virtual
 void MessageAdmin::close_view( const std::string& url )
 {
 #ifdef _DEBUG
@@ -84,7 +128,7 @@ void MessageAdmin::close_view( const std::string& url )
     SKELETON::View *view = get_current_view();
     if( ! view ) return;
 
-    if( view->set_command( "loading" ) ){
+    if( view->is_loading() ){
         SKELETON::MsgDiag mdiag( get_win(), "書き込み中です" );
         mdiag.run();
         return;
@@ -94,7 +138,9 @@ void MessageAdmin::close_view( const std::string& url )
         if( ! delete_message( view ) ) return;
     }
 
-    if( ! SESSION::get_close_mes() ) view->set_command( "clear_message" );
+    if( m_toolbar ) m_toolbar->clear_new_subject();
+
+    if( view->is_locked() ) view->set_command( "clear_message" );
     else{
         Admin::close_view( url );
         if( empty() ) close_window();
@@ -105,6 +151,7 @@ void MessageAdmin::close_view( const std::string& url )
 //
 // ウィンドウ開く
 //
+// virtual
 void MessageAdmin::open_window()
 {
     SKELETON::JDWindow* win = get_jdwin();
@@ -130,6 +177,7 @@ void MessageAdmin::open_window()
 //
 // ウィンドウ閉じる
 //
+// virtual
 void MessageAdmin::close_window()
 {
     if( get_jdwin() ){
@@ -143,12 +191,14 @@ void MessageAdmin::close_window()
 }
 
 
+// virtual
 void MessageAdmin::switch_admin()
 {
     if( ! has_focus() ) CORE::core_set_command( "switch_message" );
 }
 
 
+// virtual
 void MessageAdmin::tab_left()
 {
     SKELETON::View *view = get_current_view();
@@ -156,6 +206,7 @@ void MessageAdmin::tab_left()
 }
 
 
+// virtual
 void MessageAdmin::tab_right()
 {
     SKELETON::View *view = get_current_view();
@@ -169,11 +220,12 @@ void MessageAdmin::tab_right()
 //
 // command.arg2 == "new" なら新スレ
 //
+// virtual
 void MessageAdmin::open_view( const COMMAND_ARGS& command )
 {
-    std::string url = command.url;
-    std::string msg = command.arg1;
-    bool new_thread = ( command.arg2 == "new" );
+    const std::string url = command.url;
+    const std::string msg = command.arg1;
+    const bool new_thread = ( command.arg2 == "new" );
 
 #ifdef _DEBUG
     std::cout << "MessageAdmin::open_view " << url << std::endl;
@@ -182,7 +234,7 @@ void MessageAdmin::open_view( const COMMAND_ARGS& command )
     SKELETON::View *current_view = get_current_view();
     if( current_view ){
 
-        if( current_view->set_command( "loading" ) ){
+        if( current_view->is_loading() ){
             SKELETON::MsgDiag mdiag( get_win(), "書き込み中です" );
             mdiag.run();
             return;
@@ -206,6 +258,8 @@ void MessageAdmin::open_view( const COMMAND_ARGS& command )
         int page = get_notebook()->get_current_page();
         get_notebook()->remove_page( page );
         delete current_view;
+
+        if( m_toolbar ) m_toolbar->clear_new_subject();
     }
 
     std::string url_msg;
@@ -218,15 +272,17 @@ void MessageAdmin::open_view( const COMMAND_ARGS& command )
     }
 
     // 新スレ
-    // スレッドの id は 0000000000.(各板別の拡張子) とする。
+    // スレッドの id は ID_OF_NEWTHREAD.(各板別の拡張子) とする。
     else{
         type = CORE::VIEW_NEWTHREAD;
         args.arg1 = msg;
-        url_msg = DBTREE::url_datbase( url ) + "0000000000" + DBTREE::board_ext( url );
+        url_msg = DBTREE::url_datbase( url ) + ID_OF_NEWTHREAD + DBTREE::board_ext( url );
     }
 
-    SKELETON::View *view = CORE::ViewFactory( type, url_msg, args );
+    // ツールバー表示
+    show_toolbar();
 
+    SKELETON::View *view = CORE::ViewFactory( type, url_msg, args );
     get_notebook()->append_page( url_msg, *view );
 
     // ウィンドウ表示
@@ -236,11 +292,52 @@ void MessageAdmin::open_view( const COMMAND_ARGS& command )
     switch_admin();
     view->show();
     view->show_view();
+
+    get_notebook()->set_current_toolbar( view->get_id_toolbar(), view );
+
     set_current_page( get_notebook()->page_num( *view ) );
     focus_current_view();
 }
 
 
+
+//
+// ステータス表示
+//
+// virtual
+void MessageAdmin::set_status( const std::string& url, const std::string& stat, const bool force )
+{
+    // 埋め込みビューで、実況中の場合はステータス表示しない
+    if( SESSION::get_embedded_mes() && SESSION::is_live( url ) ) return;
+
+    SKELETON::Admin::set_status( url, stat, force );
+}
+
+
+//
+// ツールバー表示
+//
+// virtual
+void MessageAdmin::show_toolbar()
+{
+    if( ! m_toolbar ){
+
+        // 通常のツールバー
+        m_toolbar = new MessageToolBar();
+        get_notebook()->append_toolbar( *m_toolbar );
+        m_toolbar->open_buttonbar();
+
+        // プレビュー用のツールバー
+        m_toolbar_preview = new MessageToolBarPreview();
+        get_notebook()->append_toolbar( *m_toolbar_preview );
+        m_toolbar_preview->open_buttonbar();
+    }
+
+    get_notebook()->show_toolbar();
+}
+
+
+
 //
 // メッセージを破棄するか尋ねる
 //
@@ -252,7 +349,7 @@ bool MessageAdmin::delete_message( SKELETON::View * view )
                              "編集中のメッセージを閉じる前に内容を保存しますか？\n\n保存ボタンを押すとメッセージを保存できます。",
                              false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
 
-    mdiag.add_button( "保存せずに閉じる(_W)", Gtk::RESPONSE_NO );
+    mdiag.add_button( "保存せずに閉じる(_Q)", Gtk::RESPONSE_NO );
     mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
     mdiag.add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_YES );
     mdiag.set_default_response( Gtk::RESPONSE_YES );
@@ -268,7 +365,7 @@ bool MessageAdmin::delete_message( SKELETON::View * view )
             break;
 
         case Gtk::RESPONSE_YES:
-            view->set_command( "save_message" );
+            if( ! view->set_command( "save_message" ) ) return delete_message( view );
             result = true;
             break;
     }
